# Changelog

## [0.1.4](https://github.com/erikmunkby/yamlium/compare/v0.1.3...v0.1.4) (2025-06-08)


### Bug Fixes

* typing on default value ([e524ade](https://github.com/erikmunkby/yamlium/commit/e524adea105d9e0ef9cb6efbe372668e9a7f0f21))

## [0.1.3](https://github.com/erikmunkby/yamlium/compare/v0.1.2...v0.1.3) (2025-06-06)


### Bug Fixes

* remove test pypi ([e195642](https://github.com/erikmunkby/yamlium/commit/e195642eb113eb16df3a440e374112cebc922003))

## [0.1.2](https://github.com/erikmunkby/yamlium/compare/v0.1.1...v0.1.2) (2025-06-06)


### Bug Fixes

* add normal pypi publishing ([4299b3b](https://github.com/erikmunkby/yamlium/commit/4299b3b40bf70b46039ca8d1d18855154b4f169c))

## [0.1.1](https://github.com/erikmunkby/yamlium/compare/v0.1.0...v0.1.1) (2025-06-06)


### Bug Fixes

* pypi descriptions ([32b102e](https://github.com/erikmunkby/yamlium/commit/32b102ecf754f19cf68e8473c8cdf5eb0e07a2a9))

## 0.1.0 (2025-06-06)


### Features

* initial release ([c2a0afd](https://github.com/erikmunkby/yamlium/commit/c2a0afd3f3e4b3b000a9af59dd212418836aa408))
